EvmSpecId

Trait EvmSpecId 

pub trait EvmSpecId: Ord {
    // Required methods
    fn has_eip4788(&self) -> bool;
    fn has_eip2935(&self) -> bool;
    fn to_u32(&self) -> u32;
}
Steel abstraction of the EVM specification identifier (e.g., London, Shanghai).

Required Methods

fn has_eip4788(&self) -> bool

Whether EIP-4788 has been activated.

fn has_eip2935(&self) -> bool

Whether EIP-2935 has been activated.

fn to_u32(&self) -> u32

Converts the specification ID into an u32. This is used to compute ChainSpec::digest().

This must return a unique integer for each distinct specification. Different chains can have clashing specifications as long as their chain IDs are different.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl EvmSpecId for SpecId

Source

fn has_eip4788(&self) -> bool

Source

fn has_eip2935(&self) -> bool

Source

fn to_u32(&self) -> u32

Implementors