pub trait EvmDatabase: RevmDatabase {
// Required method
fn logs(
&mut self,
filter: Filter,
) -> Result<Vec<Log>, <Self as RevmDatabase>::Error>;
}Expand description
A database abstraction for the Steel EVM.
Required Methods
Sourcefn logs(
&mut self,
filter: Filter,
) -> Result<Vec<Log>, <Self as RevmDatabase>::Error>
fn logs( &mut self, filter: Filter, ) -> Result<Vec<Log>, <Self as RevmDatabase>::Error>
Retrieves all the logs matching the given [Filter].
It returns an error, if the corresponding logs cannot be retrieved from DB. The filter must match the block hash corresponding to the DB, it will panic otherwise.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementors
impl<DB: EvmDatabase> EvmDatabase for ProofDb<DB>
Available on crate feature
host only.impl<N: Network, P: Provider<N>> EvmDatabase for ProviderDb<N, P>
Available on crate feature
host only.