pub trait EvmSpecId: Ord {
// Required methods
fn has_eip4788(&self) -> bool;
fn has_eip2935(&self) -> bool;
fn to_u32(&self) -> u32;
}Expand description
Steel abstraction of the EVM specification identifier (e.g., London, Shanghai).
Required Methods
Sourcefn has_eip4788(&self) -> bool
fn has_eip4788(&self) -> bool
Whether EIP-4788 has been activated.
Sourcefn has_eip2935(&self) -> bool
fn has_eip2935(&self) -> bool
Whether EIP-2935 has been activated.
Sourcefn to_u32(&self) -> u32
fn to_u32(&self) -> u32
Converts the specification ID into an u32. This is used to compute ChainSpec::digest().
This must return a unique integer for each distinct specification. Different chains can have clashing specifications as long as their chain IDs are different.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".